@@ -5,6 +5,7 @@ import numpy as np
 import logging
 from collections import abc
 from typing import Iterable, List, NamedTuple, Any
+from numbers import Number
 
 from signum.tools.plotting_tools import adjust_plot_scale
 
@@ -111,6 +112,9 @@ class SignalContainer(np.ndarray):
         # update the instance attributes with the final set
         self.__dict__.update(_attributes)
 
+    def toarray(self):
+        return self.view(np.ndarray)
+
     @property
     def defaults(self):
         """Return a dictionary of the default values for the envelope attributes."""
@@ -247,15 +251,13 @@ class SignalContainer(np.ndarray):
         res = super().__getitem__(item)
 
         if isinstance(res, type(self)):
-            if isinstance(item, tuple):
-                item = item[0]
+            if isinstance(item, (Number, slice, np.ndarray)):
+                item = (item, )
 
-            if not isinstance(item, slice) or self._nonstandard_x_axis is not None:
-                res._nonstandard_x_axis = self.x_axis[item]  # nonstandard choice of indices
-            else:
-                res.x_start = self.x_axis[item][0] if res.size else (self.x_axis[0] if self.size else 0)
-                if item.step is not None:
-                    res._base_resolution *= item.step
+            if isinstance(item, tuple):
+                item = item[(self.ndim - self.x_axis.ndim):]
+
+            res._nonstandard_x_axis = self.x_axis[item]  # nonstandard choice of indices
 
         return res
 
@@ -469,3 +471,9 @@ class SignalContainer(np.ndarray):
         adjust_plot_scale(ax, y_unit=self.unit, y_label=self.description)
 
         return fig, axes
+
+    def _check_x_axis_spacing(self, label='requested operation'):
+        if self._nonstandard_x_axis is not None:
+            if np.unique(np.diff(self._nonstandard_x_axis)).size > 1:
+                raise ValueError(f"Cannot perform {label} on an array of non-equally spaced samples")
+
